@@ -76,6 +76,25 @@ size_allocate (PanelApplet  *applet,
     drive_list_set_panel_size (drive_list, size);
 }
 
+static void
+change_background (PanelApplet               *applet,
+		   PanelAppletBackgroundType  type,
+		   GdkColor                  *colour,
+		   GdkPixmap                 *pixmap,
+		   DriveList                 *drivelist)
+{
+    switch (type) {
+    case PANEL_NO_BACKGROUND:
+	drive_list_set_transparent (drivelist, FALSE);
+	break;
+
+    case PANEL_COLOR_BACKGROUND:
+    case PANEL_PIXMAP_BACKGROUND:
+	drive_list_set_transparent (drivelist, TRUE);
+	break;
+    }
+}
+
 static void
 display_about_dialog (BonoboUIComponent *uic,
 		      DriveList *drive_list,
@@ -163,6 +182,8 @@ applet_factory (PanelApplet *applet,
 				 G_CALLBACK (change_orient), drive_list, 0);
 	g_signal_connect_object (applet, "size_allocate",
 				 G_CALLBACK (size_allocate), drive_list, 0);
+	g_signal_connect (applet, "change_background",
+			  G_CALLBACK (change_background), drive_list);
 
 	/* set initial state */
 	change_orient (applet,
