@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.100 2005/12/12 00:22:17 philipl Exp $ */
+/* $Id: gweather-applet.c,v 1.108 2006/08/07 14:55:47 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -25,6 +25,7 @@
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
+#include <libnotify/notification.h>
 #endif
 
 #include "gweather.h"
@@ -35,6 +36,85 @@
 
 #define MAX_CONSECUTIVE_FAULTS (3)
 
+static void about_cb (BonoboUIComponent *uic,
+		      GWeatherApplet    *gw_applet,
+		      const gchar       *verbname)
+{
+
+    gweather_about_run (gw_applet);
+}
+
+static void help_cb (BonoboUIComponent *uic,
+		     GWeatherApplet    *gw_applet,
+		     const gchar       *verbname)
+{
+    GError *error = NULL;
+
+    gnome_help_display_on_screen (
+		"gweather", NULL,
+		gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
+		&error);
+
+    if (error) { 
+	GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+						    _("There was an error displaying help: %s"), error->message);
+	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
+	gtk_widget_show (dialog);
+        g_error_free (error);
+        error = NULL;
+    }
+}
+
+static void pref_cb (BonoboUIComponent *uic,
+		     GWeatherApplet    *gw_applet,
+		     const gchar       *verbname)
+{
+   if (gw_applet->pref_dialog) {
+	gtk_window_present (GTK_WINDOW (gw_applet->pref_dialog));
+   } else {
+	gw_applet->pref_dialog = gweather_pref_new(gw_applet);
+	g_object_add_weak_pointer(G_OBJECT(gw_applet->pref_dialog),
+				  (gpointer *)&(gw_applet->pref_dialog));
+	/* XXX: This should not be necessary */
+	gtk_widget_show_all (gw_applet->pref_dialog);
+   }
+}
+
+static void details_cb (BonoboUIComponent *uic,
+		         GWeatherApplet    *gw_applet,
+			 const gchar       *verbname)
+{
+   if (gw_applet->details_dialog) {
+	gtk_window_present (GTK_WINDOW (gw_applet->details_dialog));
+   } else {
+	gw_applet->details_dialog = gweather_dialog_new(gw_applet);
+	g_object_add_weak_pointer(G_OBJECT(gw_applet->details_dialog),
+				  (gpointer *)&(gw_applet->details_dialog));
+	gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+	gtk_widget_show (gw_applet->details_dialog);
+   }
+}
+
+static void update_cb (BonoboUIComponent *uic,
+		       GWeatherApplet    *gw_applet,
+		       const gchar       *verbname)
+{
+    gweather_update (gw_applet);
+}
+
+
+static const BonoboUIVerb weather_applet_menu_verbs [] = {
+	BONOBO_UI_UNSAFE_VERB ("Details", details_cb),
+	BONOBO_UI_UNSAFE_VERB ("Update", update_cb),
+        BONOBO_UI_UNSAFE_VERB ("Props", pref_cb),
+        BONOBO_UI_UNSAFE_VERB ("Help", help_cb), 
+        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
+
+        BONOBO_UI_VERB_END
+};
+
 static void place_widgets (GWeatherApplet *gw_applet)
 {
     GtkRequisition req;
@@ -133,48 +213,6 @@ static void size_allocate_cb(PanelApplet *w, GtkAllocation *allocation, gpointer
     return;
 }
 
-static void change_background_cb (
-				PanelApplet *a, 
-				PanelAppletBackgroundType type,
-				GdkColor *color, GdkPixmap *pixmap, 
-				gpointer data)
-{
-	/* taken from the TrashApplet */
-	GWeatherApplet *gw_applet = (GWeatherApplet *) data;
-	GtkRcStyle *rc_style;
-	GtkStyle *style;
-
-	/* reset style */
-	gtk_widget_set_style (GTK_WIDGET (gw_applet->applet), NULL);
-	rc_style = gtk_rc_style_new ();
-	gtk_widget_modify_style (GTK_WIDGET (gw_applet->applet), rc_style);
-	g_object_unref (rc_style);
-
-	switch (type) {
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (gw_applet->applet),
-					GTK_STATE_NORMAL, color);
-			break;
-
-		case PANEL_PIXMAP_BACKGROUND:
-			style = gtk_style_copy (
-					GTK_WIDGET (gw_applet->applet)->style);
-			if (style->bg_pixmap[GTK_STATE_NORMAL])
-				g_object_unref
-					(style->bg_pixmap[GTK_STATE_NORMAL]);
-			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
-				(pixmap);
-			gtk_widget_set_style (GTK_WIDGET (gw_applet->applet),
-					style);
-			break;
-
-		case PANEL_NO_BACKGROUND:
-		default:
-			break;
-	}
-}
-
-
 static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
@@ -183,10 +221,10 @@ static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data
         return FALSE;
 
     if (ev->type == GDK_BUTTON_PRESS) {
-	if (!gw_applet->gweather_dialog)
-		gweather_dialog_open (gw_applet);
+	if (!gw_applet->details_dialog)
+		details_cb (NULL, gw_applet, NULL);
 	else
-		gweather_dialog_close (gw_applet);
+		gtk_widget_destroy (GTK_WIDGET (gw_applet->details_dialog));
 	
 	return TRUE;
     }
@@ -206,7 +244,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 		break;
 	case GDK_d:
 		if (event->state == GDK_CONTROL_MASK) {
-			gweather_dialog_open (gw_applet);
+			details_cb (NULL, gw_applet, NULL);
 			return TRUE;
 		}
 		break;		
@@ -216,7 +254,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 	case GDK_Return:
 	case GDK_space:
 	case GDK_KP_Space:
-		gweather_dialog_open(gw_applet);
+		details_cb (NULL, gw_applet, NULL);
 		return TRUE;
 	default:
 		break;
@@ -226,93 +264,30 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 
 }
 
-static void about_cb (BonoboUIComponent *uic,
-		      GWeatherApplet    *gw_applet,
-		      const gchar       *verbname)
-{
-
-    gweather_about_run (gw_applet);
-}
-
-static void help_cb (BonoboUIComponent *uic,
-		     GWeatherApplet    *gw_applet,
-		     const gchar       *verbname)
-{
-    GError *error = NULL;
-
-    gnome_help_display_on_screen (
-		"gweather", NULL,
-		gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
-		&error);
-
-    if (error) { 
-	GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-						    _("There was an error displaying help: %s"), error->message);
-	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
-	gtk_widget_show (dialog);
-        g_error_free (error);
-        error = NULL;
-    }
-}
-
-static void pref_cb (BonoboUIComponent *uic,
-		     GWeatherApplet    *gw_applet,
-		     const gchar       *verbname)
-{
-    gweather_pref_run (gw_applet);
-}
-
-static void details_cb (BonoboUIComponent *uic,
-		         GWeatherApplet    *gw_applet,
-			 const gchar       *verbname)
-{
-    gweather_dialog_open (gw_applet);
-}
-
-static void update_cb (BonoboUIComponent *uic,
-		       GWeatherApplet    *gw_applet,
-		       const gchar       *verbname)
-{
-    gweather_update (gw_applet);
-}
-
-
-static const BonoboUIVerb weather_applet_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("Details", details_cb),
-	BONOBO_UI_UNSAFE_VERB ("Update", update_cb),
-        BONOBO_UI_UNSAFE_VERB ("Props", pref_cb),
-        BONOBO_UI_UNSAFE_VERB ("Help", help_cb), 
-        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
-
-        BONOBO_UI_VERB_END
-};
-
 static void
 applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
 {
-    if (gw_applet->pref)
-       gtk_widget_destroy (gw_applet->pref);
+    if (gw_applet->pref_dialog)
+       gtk_widget_destroy (gw_applet->pref_dialog);
 
-    if (gw_applet->about_dialog)
-	gtk_widget_destroy (gw_applet->about_dialog);
-
-    if (gw_applet->gweather_dialog)
-       gtk_widget_destroy (gw_applet->gweather_dialog);
+    if (gw_applet->details_dialog)
+       gtk_widget_destroy (gw_applet->details_dialog);
 
     if (gw_applet->timeout_tag > 0) {
        gtk_timeout_remove(gw_applet->timeout_tag);
        gw_applet->timeout_tag = 0;
     }
 	
+    if (gw_applet->suncalc_timeout_tag > 0) {
+       gtk_timeout_remove(gw_applet->suncalc_timeout_tag);
+       gw_applet->suncalc_timeout_tag = 0;
+    }
+	
     if (gw_applet->gconf) {
        gweather_gconf_free (gw_applet->gconf);
     }
 
     weather_info_abort (gw_applet->gweather_info);
-
-    gtk_main_quit ();
 }
 
 void gweather_applet_create (GWeatherApplet *gw_applet)
@@ -321,8 +296,6 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     GtkIconInfo *icon_info;
     AtkObject *atk_obj;
 
-    gw_applet->about_dialog = NULL;
- 
     gw_applet->gweather_pref.location = NULL;
     gw_applet->gweather_pref.update_interval = 1800;
     gw_applet->gweather_pref.update_enabled = TRUE;
@@ -334,6 +307,9 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 	gw_applet->gweather_pref.distance_unit = DISTANCE_UNIT_INVALID;
     
     panel_applet_set_flags (gw_applet->applet, PANEL_APPLET_EXPAND_MINOR);
+
+    panel_applet_set_background_widget(gw_applet->applet,
+                                       GTK_WIDGET(gw_applet->applet));
     
     icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "stock_weather-storm", 48, 0);
     if (icon_info) {
@@ -348,8 +324,6 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
                        G_CALLBACK(change_orient_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "size_allocate",
                        G_CALLBACK(size_allocate_cb), gw_applet);
-    g_signal_connect (G_OBJECT(gw_applet->applet), "change_background",
-		       G_CALLBACK(change_background_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
                        G_CALLBACK (applet_destroy), gw_applet);
     g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
@@ -407,26 +381,31 @@ update_finish (WeatherInfo *info, gpointer data)
 {
     static int gw_fault_counter = 0;
 #ifdef HAVE_LIBNOTIFY
-    static NotifyIcon *icon = NULL;
-    NotifyHints *hints;
-    char *notification_message, *notification_detail;
+    char *message, *detail;
     GdkPixbuf *pixbuf = NULL;
     GConfClient *conf;
-    int x, y;
-    GtkRequisition size;
 #endif
     char *s;
     GWeatherApplet *gw_applet = (GWeatherApplet *)data;
-   
+    gint nxtSunEvent;
+
     /* Update timer */
     if (gw_applet->timeout_tag > 0)
         gtk_timeout_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
-        gw_applet->timeout_tag =  
-        	gtk_timeout_add (
-			gw_applet->gweather_pref.update_interval * 1000,
+    {
+	gw_applet->timeout_tag =
+		gtk_timeout_add (
+                       gw_applet->gweather_pref.update_interval * 1000,
                         timeout_cb, gw_applet);
- 
+
+        nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
+        if (nxtSunEvent >= 0)
+            gw_applet->suncalc_timeout_tag =
+                        gtk_timeout_add (nxtSunEvent * 1000,
+                                suncalc_timeout_cb, gw_applet);
+    }
+
     if ((TRUE == weather_info_is_valid (info)) ||
 	     (gw_fault_counter >= MAX_CONSECUTIVE_FAULTS))
     {
@@ -444,77 +423,58 @@ update_finish (WeatherInfo *info, gpointer data)
 	    gtk_tooltips_set_tip (gw_applet->tooltips, GTK_WIDGET (
 				    gw_applet->applet), s, NULL);
 	    g_free (s);
-	    
+
 	    /* Update dialog -- if one is present */
-	    gweather_dialog_update(gw_applet);
-	    
+	    if (gw_applet->details_dialog) {
+	    	gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+	    }
+
+	    /* update applet */
+	    place_widgets(gw_applet);
+
 #ifdef HAVE_LIBNOTIFY
-            conf = gconf_client_get_default ();
-            if (!gconf_client_get_bool (conf, "/apps/panel/applets/weather/use_libnotify", NULL))
-            {
-                g_object_unref (conf);
-                return;
-            }
-            g_object_unref (conf);
+	    if (panel_applet_gconf_get_bool (gw_applet->applet,
+				    "show_notifications", NULL))
+	    {
+		    NotifyNotification *n;
+	            
+		    /* Show notifications if possible */
+	            if (!notify_is_initted ())
+	                notify_init (_("Weather Forecast"));
 
-            /* Show notifications if possible */
-            if (!notify_is_initted ())
-                if (!notify_init (_("Weather Forecast")))
-                    return;
-            
-            /* Get the icon for the notification message */
-            if (icon) {
-                notify_icon_destroy (icon);
-                icon = NULL;
-            }
-            weather_info_get_pixbuf (gw_applet->gweather_info, &pixbuf);
-            if (pixbuf) {
-                gchar *tmp;
-                GError *error = NULL;
-                
-                tmp = g_strdup_printf ("%s/.gnome2/gweather-icon.png", g_get_home_dir ());
-                if (gdk_pixbuf_save (pixbuf, tmp, "png", &error, NULL))
-                    icon = notify_icon_new_from_uri (tmp);
-                else
-                    g_warning ("Unable to save weather icon: %s\n", error->message);
-                
-                if (error != NULL)
-                    g_error_free (error);
-                
-                g_free (tmp);
-            }
-            
-	    gdk_window_get_origin (GTK_WIDGET (gw_applet->applet)->window, &x, &y);
-	    gtk_widget_size_request (GTK_WIDGET (gw_applet->applet), &size);
-	    x += size.width / 2;
-	    y += size.height;
-
-	    hints = notify_hints_new ();
-	    notify_hints_set_int (hints, "x", x);
-	    notify_hints_set_int (hints, "y", y);
-	    
-            /* Show notification */
-            notification_message = g_strdup_printf ("%s: %s",
-                                                    weather_info_get_location_name (info),
-                                                    weather_info_get_sky (info));
-            notification_detail = g_strdup_printf (_("City: %s\nSky: %s\nTemperature: %s"),
-            		                           weather_info_get_location_name (info),
-            		                           weather_info_get_sky (info),
-            		                           weather_info_get_temp_summary (info));
-            
-            if (!notify_send_notification (NULL, "transfer",
-                                           NOTIFY_URGENCY_LOW,
-	                                   notification_message,
-	                                   notification_detail,	/* body text */
-	                                   icon,		/* icon */
-	                                   TRUE, 0,		/* expiry, server default */
-	                                   hints,		/* hints */
-	                                   NULL,		/* no user_data */
-	                                   0))			/* no actions */
-	        g_warning ("Could not send notification to daemon\n");
-
-	    g_free (notification_message);
-	    g_free (notification_detail);
+		    if (notify_is_initted ())
+		    {
+			 GError *error = NULL;
+			 
+	           	 /* Show notification */
+	           	 message = g_strdup_printf ("%s: %s",
+					 weather_info_get_location_name (info),
+					 weather_info_get_sky (info));
+	           	 detail = g_strdup_printf (
+					 _("City: %s\nSky: %s\nTemperature: %s"),
+					 weather_info_get_location_name (info),
+					 weather_info_get_sky (info),
+					 weather_info_get_temp_summary (info));
+	           	 
+			 n = notify_notification_new (message, detail, NULL,
+					 gw_applet->container);
+	
+			 /* set the pixbuf */
+	           	 weather_info_get_pixbuf (gw_applet->gweather_info,
+					 &pixbuf);
+	 	   	 if (pixbuf)
+	 	   	    notify_notification_set_icon_from_pixbuf (n, pixbuf);
+		   	 notify_notification_show (n, &error);
+			 if (error)
+			 {
+				 g_warning (error->message);
+				 g_error_free (error);
+			 }
+		   	     
+		   	 g_free (message);
+		   	 g_free (detail);
+		    }
+	    }
 #endif
     }
     else
@@ -526,6 +486,14 @@ update_finish (WeatherInfo *info, gpointer data)
     }
 }
 
+gint suncalc_timeout_cb (gpointer data)
+{
+    WeatherInfo *info = ((GWeatherApplet *)data)->gweather_info;
+    update_finish(info, data);
+    return 0;  /* Do not repeat timeout (will be re-set by update_finish) */
+}
+
+
 void gweather_update (GWeatherApplet *gw_applet)
 {
     WeatherPrefs prefs;
