@@ -164,47 +164,6 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 	return;
 }
 
-static void
-multiload_change_background_cb (PanelApplet *a,
-				PanelAppletBackgroundType type,
-				GdkColor *color,
-				GdkPixmap *pixmap,
-				gpointer *data)
-{
-	/* Taken from Trash Applet */
-	MultiloadApplet *ma = (MultiloadApplet *) data;
-	GtkRcStyle *rc_style;
-	GtkStyle *style;
-	
-	/* reset style */
-	gtk_widget_set_style (GTK_WIDGET (ma->applet), NULL);
-	rc_style = gtk_rc_style_new ();
-	gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
-	gtk_rc_style_unref (rc_style);
-
-	switch (type) {
-		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg (GTK_WIDGET (ma->applet),
-					GTK_STATE_NORMAL, color);
-			break;
-
-		case PANEL_PIXMAP_BACKGROUND:
-			style = gtk_style_copy (GTK_WIDGET (ma->applet)->style);
-			if (style->bg_pixmap[GTK_STATE_NORMAL])
-				g_object_unref
-					(style->bg_pixmap[GTK_STATE_NORMAL]);
-			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref
-				(pixmap);
-			gtk_widget_set_style (GTK_WIDGET (ma->applet), style);
-			g_object_unref (style);
-			break;
-
-		case PANEL_NO_BACKGROUND:
-		default:
-			break;
-	}
-}
-
 static void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
@@ -256,7 +215,7 @@ multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 	return TRUE;
 }
 
-#if 0
+
 static gboolean
 multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 {
@@ -266,12 +225,11 @@ multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 	ma = (MultiloadApplet *)data;
 
 	for (i = 0; i < NGRAPHS; i++)
-		if (ma->graphs[i]->visible)
 			ma->graphs[i]->tooltip_update = FALSE;
 		
 	return TRUE;
 }
-#endif /* 0 */
+
 
 static gboolean
 multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
@@ -514,6 +472,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
         ma->last_clicked = 0;
 
 	gtk_window_set_default_icon_name ("gnome-monitor");
+	panel_applet_set_background_widget (applet, GTK_WIDGET(applet));
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
@@ -549,12 +508,12 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 				G_CALLBACK(multiload_change_size_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "change_orient",
 				G_CALLBACK(multiload_change_orient_cb), ma);
-	g_signal_connect(G_OBJECT(applet), "change_background",
-				G_CALLBACK(multiload_change_background_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "destroy",
 				G_CALLBACK(multiload_destroy_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
 				G_CALLBACK(multiload_enter_cb), ma);
+	g_signal_connect(G_OBJECT(applet), "leave_notify_event",
+				G_CALLBACK(multiload_leave_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "button_press_event",
 				G_CALLBACK(multiload_button_press_event_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "key_press_event",
